Guided Tour
=================

To help you get start with the JAX + Flax ecosystem, we suggest that you start with the following notebooks.
They will walk you through both JAX and Flax basics.
If you are already comfortable with JAX, you can skip that part and start directly with Flax.

.. toctree::
   :maxdepth: 2

   jax_for_the_impatient
   flax_basics
